@@ -25,8 +25,10 @@ from oslo_log import log as logging
 
 from os_brick import exception
 from os_brick import executor
+from os_brick.i18n import _LE
 from os_brick.i18n import _LI
 from os_brick.i18n import _LW
+from os_brick.privileged import rootwrap as priv_rootwrap
 from os_brick import utils
 
 LOG = logging.getLogger(__name__)
@@ -39,11 +41,6 @@ MULTIPATH_DEVICE_ACTIONS = ['unchanged:', 'reject:', 'reload:',
 
 
 class LinuxSCSI(executor.Executor):
-    def __init__(self, root_helper, execute=putils.execute,
-                 *args, **kwargs):
-        super(LinuxSCSI, self).__init__(root_helper, execute,
-                                        *args, **kwargs)
-
     def echo_scsi_command(self, path, content):
         """Used to echo strings to scsi subsystem."""
 
@@ -109,12 +106,27 @@ class LinuxSCSI(executor.Executor):
     def get_scsi_wwn(self, path):
         """Read the WWN from page 0x83 value for a SCSI device."""
 
-        (out, _err) = self._execute('scsi_id', '--page', '0x83',
+        (out, _err) = self._execute('/lib/udev/scsi_id', '--page', '0x83',
                                     '--whitelisted', path,
                                     run_as_root=True,
                                     root_helper=self._root_helper)
         return out.strip()
 
+    @staticmethod
+    def is_multipath_running(enforce_multipath, root_helper):
+        try:
+            priv_rootwrap.execute('multipathd', 'show', 'status',
+                                  run_as_root=True,
+                                  root_helper=root_helper)
+        except putils.ProcessExecutionError as err:
+            LOG.error(_LE('multipathd is not running: exit code %(err)s'),
+                      {'err': err.exit_code})
+            if enforce_multipath:
+                raise
+            return False
+
+        return True
+
     def remove_multipath_device(self, device):
         """This removes LUNs associated with a multipath device
         and the multipath device itself.
@@ -266,7 +278,8 @@ class LinuxSCSI(executor.Executor):
         except putils.ProcessExecutionError as exc:
             LOG.warning(_LW("multipath call failed exit %(code)s"),
                         {'code': exc.exit_code})
-            return None
+            raise exception.CommandExecutionFailed(
+                cmd='multipath -l %s' % device)
 
         if out:
             lines = out.strip()
@@ -327,7 +340,7 @@ class LinuxSCSI(executor.Executor):
         (out, _err) = self._execute('blockdev', '--getsize64',
                                     device, run_as_root=True,
                                     root_helper=self._root_helper)
-        var = six.text_type(out)
+        var = six.text_type(out.strip())
         if var.isnumeric():
             return int(var)
         else:
@@ -408,3 +421,20 @@ class LinuxSCSI(executor.Executor):
             return new_size
         else:
             return new_size
+
+    def process_lun_id(self, lun_ids):
+        if isinstance(lun_ids, list):
+            processed = []
+            for x in lun_ids:
+                x = self._format_lun_id(x)
+                processed.append(x)
+        else:
+            processed = self._format_lun_id(lun_ids)
+        return processed
+
+    def _format_lun_id(self, lun_id):
+        if lun_id < 256:
+                return lun_id
+        else:
+            return ("0x%04x%04x00000000" %
+                    (lun_id & 0xffff, lun_id >> 16 & 0xffff))
